
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class CarePlanResourceProvider extends JpaResourceProviderDstu1<CarePlan> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return CarePlan.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="condition", targetTypes={  Condition.class   } )
			ReferenceAndListParam theCondition, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="participant", targetTypes={  Practitioner.class ,   RelatedPerson.class ,   Patient.class ,   Organization.class   } )
			ReferenceAndListParam theParticipant, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="activitycode")
			TokenAndListParam theActivitycode, 
  
			@Description(shortDefinition="Specified date occurs within period specified by CarePlan.activity.timingSchedule")
			@OptionalParam(name="activitydate")
			DateRangeParam theActivitydate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="activitydetail", targetTypes={  Procedure.class ,   MedicationPrescription.class ,   DiagnosticOrder.class ,   Encounter.class   } )
			ReferenceAndListParam theActivitydetail, 


			@IncludeParam(allow= {
					"CarePlan.patient" , 						"CarePlan.concern" , 						"CarePlan.participant.member" , 						"CarePlan.activity.detail" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("patient", thePatient);	
			paramMap.add("condition", theCondition);	
			paramMap.add("date", theDate);	
			paramMap.add("participant", theParticipant);	
			paramMap.add("activitycode", theActivitycode);	
			paramMap.add("activitydate", theActivitydate);	
			paramMap.add("activitydetail", theActivitydetail);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
