
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class CompositionResourceProvider extends JpaResourceProviderDstu1<Composition> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Composition.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="class")
			TokenAndListParam theClass, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Practitioner.class ,   Group.class ,   Device.class ,   Location.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="author", targetTypes={  Practitioner.class ,   Device.class ,   Patient.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theAuthor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="attester", targetTypes={  Patient.class ,   Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam theAttester, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="context")
			TokenAndListParam theContext, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="section-type")
			TokenAndListParam theSection_type, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="section-content", targetTypes={  } )
			ReferenceAndListParam theSection_content, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 


			@IncludeParam(allow= {
					"Composition.subject" , 						"Composition.author" , 						"Composition.attester.party" , 						"Composition.section.content" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("type", theType);	
			paramMap.add("class", theClass);	
			paramMap.add("date", theDate);	
			paramMap.add("subject", theSubject);	
			paramMap.add("author", theAuthor);	
			paramMap.add("attester", theAttester);	
			paramMap.add("context", theContext);	
			paramMap.add("section-type", theSection_type);	
			paramMap.add("section-content", theSection_content);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
