
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ConformanceResourceProvider extends JpaResourceProviderDstu1<Conformance> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Conformance.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The identifier of the conformance statement")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The version identifier of the conformance statement")
			@OptionalParam(name="version")
			TokenAndListParam theVersion, 
  
			@Description(shortDefinition="Name of the conformance statement")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="Name of the publisher of the conformance statement")
			@OptionalParam(name="publisher")
			StringAndListParam thePublisher, 
  
			@Description(shortDefinition="Text search in the description of the conformance statement")
			@OptionalParam(name="description")
			StringAndListParam theDescription, 
  
			@Description(shortDefinition="The current status of the conformance statement")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="The conformance statement publication date")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="Part of a the name of a software application")
			@OptionalParam(name="software")
			StringAndListParam theSoftware, 
  
			@Description(shortDefinition="The version of FHIR")
			@OptionalParam(name="fhirversion")
			TokenAndListParam theFhirversion, 
  
			@Description(shortDefinition="Name of a resource mentioned in a conformance statement")
			@OptionalParam(name="resource")
			TokenAndListParam theResource, 
  
			@Description(shortDefinition="Event code in a conformance statement")
			@OptionalParam(name="event")
			TokenAndListParam theEvent, 
  
			@Description(shortDefinition="Mode - restful (server/client) or messaging (sender/receiver)")
			@OptionalParam(name="mode")
			TokenAndListParam theMode, 
  
			@Description(shortDefinition="A profile id invoked in a conformance statement")
			@OptionalParam(name="profile", targetTypes={  Profile.class   } )
			ReferenceAndListParam theProfile, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="format")
			TokenAndListParam theFormat, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="security")
			TokenAndListParam theSecurity, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="supported-profile", targetTypes={  Profile.class   } )
			ReferenceAndListParam theSupported_profile, 


			@IncludeParam(allow= {
					"Conformance.rest.resource.profile" , 						"Conformance.profile" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("version", theVersion);	
			paramMap.add("name", theName);	
			paramMap.add("publisher", thePublisher);	
			paramMap.add("description", theDescription);	
			paramMap.add("status", theStatus);	
			paramMap.add("date", theDate);	
			paramMap.add("software", theSoftware);	
			paramMap.add("fhirversion", theFhirversion);	
			paramMap.add("resource", theResource);	
			paramMap.add("event", theEvent);	
			paramMap.add("mode", theMode);	
			paramMap.add("profile", theProfile);	
			paramMap.add("format", theFormat);	
			paramMap.add("security", theSecurity);	
			paramMap.add("supported-profile", theSupported_profile);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
