
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class DeviceObservationReportResourceProvider extends JpaResourceProviderDstu1<DeviceObservationReport> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return DeviceObservationReport.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source", targetTypes={  Device.class   } )
			ReferenceAndListParam theSource, 
  
			@Description(shortDefinition="The compatment code")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="The channel code")
			@OptionalParam(name="channel")
			TokenAndListParam theChannel, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="observation", targetTypes={  Observation.class   } )
			ReferenceAndListParam theObservation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Device.class ,   Location.class   } )
			ReferenceAndListParam theSubject, 


			@IncludeParam(allow= {
					"DeviceObservationReport.source" , 						"DeviceObservationReport.virtualDevice.channel.metric.observation" , 						"DeviceObservationReport.subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("source", theSource);	
			paramMap.add("code", theCode);	
			paramMap.add("channel", theChannel);	
			paramMap.add("observation", theObservation);	
			paramMap.add("subject", theSubject);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
