
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class DiagnosticOrderResourceProvider extends JpaResourceProviderDstu1<DiagnosticOrder> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return DiagnosticOrder.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="actor", targetTypes={  } )
			ReferenceAndListParam theActor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="bodysite")
			TokenAndListParam theBodysite, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="event-date")
			DateRangeParam theEvent_date, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="encounter", targetTypes={  Encounter.class   } )
			ReferenceAndListParam theEncounter, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="item-date")
			DateRangeParam theItem_date, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="item-past-status")
			TokenAndListParam theItem_past_status, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="item-status")
			TokenAndListParam theItem_status, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="orderer", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theOrderer, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="event-status")
			TokenAndListParam theEvent_status, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="specimen", targetTypes={  } )
			ReferenceAndListParam theSpecimen, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Group.class ,   Location.class ,   Device.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="A combination of item-past-status and item-date")
			@OptionalParam(name="item-past-status-item-date", compositeTypes= { TokenParam.class, DateParam.class })
			CompositeAndListParam<TokenParam, DateParam> theItem_past_status_item_date,
  
			@Description(shortDefinition="A combination of past-status and date")
			@OptionalParam(name="event-status-event-date", compositeTypes= { TokenParam.class, DateParam.class })
			CompositeAndListParam<TokenParam, DateParam> theEvent_status_event_date,


			@IncludeParam(allow= {
					"DiagnosticOrder.event.actor" , 					"DiagnosticOrder.item.event.actor" , 						"DiagnosticOrder.encounter" , 						"DiagnosticOrder.orderer" , 						"DiagnosticOrder.specimen" , 					"DiagnosticOrder.item.specimen" , 						"DiagnosticOrder.subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("actor", theActor);	
			paramMap.add("bodysite", theBodysite);	
			paramMap.add("code", theCode);	
			paramMap.add("event-date", theEvent_date);	
			paramMap.add("encounter", theEncounter);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("item-date", theItem_date);	
			paramMap.add("item-past-status", theItem_past_status);	
			paramMap.add("item-status", theItem_status);	
			paramMap.add("orderer", theOrderer);	
			paramMap.add("event-status", theEvent_status);	
			paramMap.add("specimen", theSpecimen);	
			paramMap.add("status", theStatus);	
			paramMap.add("subject", theSubject);	
			paramMap.add("item-past-status-item-date", theItem_past_status_item_date);	
			paramMap.add("event-status-event-date", theEvent_status_event_date);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
