
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class DocumentReferenceResourceProvider extends JpaResourceProviderDstu1<DocumentReference> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return DocumentReference.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Practitioner.class ,   Group.class ,   Device.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="class")
			TokenAndListParam theClass, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="author", targetTypes={  Practitioner.class ,   Device.class ,   Patient.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theAuthor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="custodian", targetTypes={  Organization.class   } )
			ReferenceAndListParam theCustodian, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="authenticator", targetTypes={  Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam theAuthenticator, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="created")
			DateRangeParam theCreated, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="indexed")
			DateRangeParam theIndexed, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="relatesto", targetTypes={  DocumentReference.class   } )
			ReferenceAndListParam theRelatesto, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="relation")
			TokenAndListParam theRelation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="description")
			StringAndListParam theDescription, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="confidentiality")
			TokenAndListParam theConfidentiality, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="language")
			TokenAndListParam theLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="format")
			TokenAndListParam theFormat, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="size")
			NumberAndListParam theSize, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="location")
			StringAndListParam theLocation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="event")
			TokenAndListParam theEvent, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="period")
			DateRangeParam thePeriod, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="facility")
			TokenAndListParam theFacility, 
  
			@Description(shortDefinition="Combination of relation and relatesTo")
			@OptionalParam(name="relatesto-relation", compositeTypes= { ReferenceParam.class, TokenParam.class })
			CompositeAndListParam<ReferenceParam, TokenParam> theRelatesto_relation,


			@IncludeParam(allow= {
					"DocumentReference.subject" , 						"DocumentReference.author" , 						"DocumentReference.custodian" , 						"DocumentReference.authenticator" , 						"DocumentReference.relatesTo.target" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("subject", theSubject);	
			paramMap.add("type", theType);	
			paramMap.add("class", theClass);	
			paramMap.add("author", theAuthor);	
			paramMap.add("custodian", theCustodian);	
			paramMap.add("authenticator", theAuthenticator);	
			paramMap.add("created", theCreated);	
			paramMap.add("indexed", theIndexed);	
			paramMap.add("status", theStatus);	
			paramMap.add("relatesto", theRelatesto);	
			paramMap.add("relation", theRelation);	
			paramMap.add("description", theDescription);	
			paramMap.add("confidentiality", theConfidentiality);	
			paramMap.add("language", theLanguage);	
			paramMap.add("format", theFormat);	
			paramMap.add("size", theSize);	
			paramMap.add("location", theLocation);	
			paramMap.add("event", theEvent);	
			paramMap.add("period", thePeriod);	
			paramMap.add("facility", theFacility);	
			paramMap.add("relatesto-relation", theRelatesto_relation);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
