
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class GroupResourceProvider extends JpaResourceProviderDstu1<Group> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Group.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The type of resources the group contains")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="The kind of resources contained")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="actual")
			TokenAndListParam theActual, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="member", targetTypes={  Patient.class ,   Practitioner.class ,   Device.class ,   Medication.class ,   Substance.class   } )
			ReferenceAndListParam theMember, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="characteristic")
			TokenAndListParam theCharacteristic, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="value")
			TokenAndListParam theValue, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="exclude")
			TokenAndListParam theExclude, 
  
			@Description(shortDefinition="A composite of both characteristic and value")
			@OptionalParam(name="characteristic-value", compositeTypes= { TokenParam.class, TokenParam.class })
			CompositeAndListParam<TokenParam, TokenParam> theCharacteristic_value,


			@IncludeParam(allow= {
					"Group.member" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("type", theType);	
			paramMap.add("code", theCode);	
			paramMap.add("actual", theActual);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("member", theMember);	
			paramMap.add("characteristic", theCharacteristic);	
			paramMap.add("value", theValue);	
			paramMap.add("exclude", theExclude);	
			paramMap.add("characteristic-value", theCharacteristic_value);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
