
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ImagingStudyResourceProvider extends JpaResourceProviderDstu1<ImagingStudy> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ImagingStudy.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Who the study is about")
			@OptionalParam(name="subject", targetTypes={  Patient.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="The date the study was done was taken")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="The accession id for the image")
			@OptionalParam(name="accession")
			TokenAndListParam theAccession, 
  
			@Description(shortDefinition="The study id for the image")
			@OptionalParam(name="study")
			TokenAndListParam theStudy, 
  
			@Description(shortDefinition="The series id for the image")
			@OptionalParam(name="series")
			TokenAndListParam theSeries, 
  
			@Description(shortDefinition="The modality of the image")
			@OptionalParam(name="modality")
			TokenAndListParam theModality, 
  
			@Description(shortDefinition="The size of the image in MB - may include > or < in the value")
			@OptionalParam(name="size")
			NumberAndListParam theSize, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="bodysite")
			TokenAndListParam theBodysite, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="uid")
			TokenAndListParam theUid, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dicom-class")
			TokenAndListParam theDicom_class, 


			@IncludeParam(allow= {
					"ImagingStudy.subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("subject", theSubject);	
			paramMap.add("date", theDate);	
			paramMap.add("accession", theAccession);	
			paramMap.add("study", theStudy);	
			paramMap.add("series", theSeries);	
			paramMap.add("modality", theModality);	
			paramMap.add("size", theSize);	
			paramMap.add("bodysite", theBodysite);	
			paramMap.add("uid", theUid);	
			paramMap.add("dicom-class", theDicom_class);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
