
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ImmunizationResourceProvider extends JpaResourceProviderDstu1<Immunization> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Immunization.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Vaccination  Administration / Refusal Date")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dose-sequence")
			NumberAndListParam theDose_sequence, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The service delivery location or facility in which the vaccine was / was to be administered")
			@OptionalParam(name="location", targetTypes={  Location.class   } )
			ReferenceAndListParam theLocation, 
  
			@Description(shortDefinition="Vaccine Lot Number")
			@OptionalParam(name="lot-number")
			StringAndListParam theLot_number, 
  
			@Description(shortDefinition="Vaccine Manufacturer")
			@OptionalParam(name="manufacturer", targetTypes={  Organization.class   } )
			ReferenceAndListParam theManufacturer, 
  
			@Description(shortDefinition="The practitioner who administered the vaccination")
			@OptionalParam(name="performer", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam thePerformer, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reaction", targetTypes={  AdverseReaction.class ,   Observation.class   } )
			ReferenceAndListParam theReaction, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reaction-date")
			DateRangeParam theReaction_date, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reason")
			TokenAndListParam theReason, 
  
			@Description(shortDefinition="Explanation of refusal / exemption")
			@OptionalParam(name="refusal-reason")
			TokenAndListParam theRefusal_reason, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="refused")
			TokenAndListParam theRefused, 
  
			@Description(shortDefinition="The practitioner who ordered the vaccination")
			@OptionalParam(name="requester", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theRequester, 
  
			@Description(shortDefinition="The subject of the vaccination event / refusal")
			@OptionalParam(name="subject", targetTypes={  Patient.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="Vaccine Product Type Administered")
			@OptionalParam(name="vaccine-type")
			TokenAndListParam theVaccine_type, 


			@IncludeParam(allow= {
					"Immunization.location" , 						"Immunization.manufacturer" , 						"Immunization.performer" , 						"Immunization.reaction.detail" , 						"Immunization.requester" , 						"Immunization.subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("date", theDate);	
			paramMap.add("dose-sequence", theDose_sequence);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("location", theLocation);	
			paramMap.add("lot-number", theLot_number);	
			paramMap.add("manufacturer", theManufacturer);	
			paramMap.add("performer", thePerformer);	
			paramMap.add("reaction", theReaction);	
			paramMap.add("reaction-date", theReaction_date);	
			paramMap.add("reason", theReason);	
			paramMap.add("refusal-reason", theRefusal_reason);	
			paramMap.add("refused", theRefused);	
			paramMap.add("requester", theRequester);	
			paramMap.add("subject", theSubject);	
			paramMap.add("vaccine-type", theVaccine_type);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
