
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class MediaResourceProvider extends JpaResourceProviderDstu1<Media> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Media.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subtype")
			TokenAndListParam theSubtype, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Practitioner.class ,   Group.class ,   Device.class ,   Specimen.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="operator", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theOperator, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="view")
			TokenAndListParam theView, 


			@IncludeParam(allow= {
					"Media.subject" , 						"Media.operator" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("type", theType);	
			paramMap.add("subtype", theSubtype);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("date", theDate);	
			paramMap.add("subject", theSubject);	
			paramMap.add("operator", theOperator);	
			paramMap.add("view", theView);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
