
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class MedicationStatementResourceProvider extends JpaResourceProviderDstu1<MedicationStatement> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return MedicationStatement.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Return administrations with this administration device identity")
			@OptionalParam(name="device", targetTypes={  Device.class   } )
			ReferenceAndListParam theDevice, 
  
			@Description(shortDefinition="Return administrations with this external identity")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="Code for medicine or text in medicine name")
			@OptionalParam(name="medication", targetTypes={  Medication.class   } )
			ReferenceAndListParam theMedication, 
  
			@Description(shortDefinition="The identity of a patient to list administrations  for")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="Date of administration")
			@OptionalParam(name="when-given")
			DateRangeParam theWhen_given, 


			@IncludeParam(allow= {
					"MedicationStatement.device" , 						"MedicationStatement.medication" , 						"MedicationStatement.patient" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("device", theDevice);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("medication", theMedication);	
			paramMap.add("patient", thePatient);	
			paramMap.add("when-given", theWhen_given);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
