
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class OrderResourceProvider extends JpaResourceProviderDstu1<Order> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Order.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theSource, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="target", targetTypes={  Organization.class ,   Device.class ,   Practitioner.class   } )
			ReferenceAndListParam theTarget, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="authority", targetTypes={  } )
			ReferenceAndListParam theAuthority, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="when_code")
			TokenAndListParam theWhen_code, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="when")
			DateRangeParam theWhen, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="detail", targetTypes={  } )
			ReferenceAndListParam theDetail, 


			@IncludeParam(allow= {
					"Order.subject" , 						"Order.source" , 						"Order.target" , 						"Order.authority" , 						"Order.detail" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("date", theDate);	
			paramMap.add("subject", theSubject);	
			paramMap.add("source", theSource);	
			paramMap.add("target", theTarget);	
			paramMap.add("authority", theAuthority);	
			paramMap.add("when_code", theWhen_code);	
			paramMap.add("when", theWhen);	
			paramMap.add("detail", theDetail);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
