
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class PatientResourceProvider extends JpaResourceProviderDstu1<Patient> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Patient.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="A patient identifier")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="A portion of either family or given name of the patient")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="A portion of the family name of the patient")
			@OptionalParam(name="family")
			StringAndListParam theFamily, 
  
			@Description(shortDefinition="A portion of the given name of the patient")
			@OptionalParam(name="given")
			StringAndListParam theGiven, 
  
			@Description(shortDefinition="A portion of either family or given name using some kind of phonetic matching algorithm")
			@OptionalParam(name="phonetic")
			StringAndListParam thePhonetic, 
  
			@Description(shortDefinition="The value in any kind of telecom details of the patient")
			@OptionalParam(name="telecom")
			StringAndListParam theTelecom, 
  
			@Description(shortDefinition="An address in any kind of address/part of the patient")
			@OptionalParam(name="address")
			StringAndListParam theAddress, 
  
			@Description(shortDefinition="Gender of the patient")
			@OptionalParam(name="gender")
			TokenAndListParam theGender, 
  
			@Description(shortDefinition="Language code (irrespective of use value)")
			@OptionalParam(name="language")
			TokenAndListParam theLanguage, 
  
			@Description(shortDefinition="The patient's date of birth")
			@OptionalParam(name="birthdate")
			DateRangeParam theBirthdate, 
  
			@Description(shortDefinition="The organization at which this person is a patient")
			@OptionalParam(name="provider", targetTypes={  Organization.class   } )
			ReferenceAndListParam theProvider, 
  
			@Description(shortDefinition="Whether the patient record is active")
			@OptionalParam(name="active")
			TokenAndListParam theActive, 
  
			@Description(shortDefinition="The species for animal patients")
			@OptionalParam(name="animal-species")
			TokenAndListParam theAnimal_species, 
  
			@Description(shortDefinition="The breed for animal patients")
			@OptionalParam(name="animal-breed")
			TokenAndListParam theAnimal_breed, 
  
			@Description(shortDefinition="All patients linked to the given patient")
			@OptionalParam(name="link", targetTypes={  Patient.class   } )
			ReferenceAndListParam theLink, 


			@IncludeParam(allow= {
					"Patient.managingOrganization" , 						"Patient.link.other" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("name", theName);	
			paramMap.add("family", theFamily);	
			paramMap.add("given", theGiven);	
			paramMap.add("phonetic", thePhonetic);	
			paramMap.add("telecom", theTelecom);	
			paramMap.add("address", theAddress);	
			paramMap.add("gender", theGender);	
			paramMap.add("language", theLanguage);	
			paramMap.add("birthdate", theBirthdate);	
			paramMap.add("provider", theProvider);	
			paramMap.add("active", theActive);	
			paramMap.add("animal-species", theAnimal_species);	
			paramMap.add("animal-breed", theAnimal_breed);	
			paramMap.add("link", theLink);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
