
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ProvenanceResourceProvider extends JpaResourceProviderDstu1<Provenance> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Provenance.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="target", targetTypes={  } )
			ReferenceAndListParam theTarget, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="start")
			DateRangeParam theStart, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="end")
			DateRangeParam theEnd, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="location", targetTypes={  Location.class   } )
			ReferenceAndListParam theLocation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="party")
			TokenAndListParam theParty, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="partytype")
			TokenAndListParam thePartytype, 


			@IncludeParam(allow= {
					"Provenance.target" , 						"Provenance.location" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("target", theTarget);	
			paramMap.add("start", theStart);	
			paramMap.add("end", theEnd);	
			paramMap.add("location", theLocation);	
			paramMap.add("party", theParty);	
			paramMap.add("partytype", thePartytype);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
