
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class SecurityEventResourceProvider extends JpaResourceProviderDstu1<SecurityEvent> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return SecurityEvent.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="action")
			TokenAndListParam theAction, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subtype")
			TokenAndListParam theSubtype, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="user")
			TokenAndListParam theUser, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="address")
			TokenAndListParam theAddress, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source")
			TokenAndListParam theSource, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="site")
			TokenAndListParam theSite, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="object-type")
			TokenAndListParam theObject_type, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identity")
			TokenAndListParam theIdentity, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reference", targetTypes={  } )
			ReferenceAndListParam theReference, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="desc")
			StringAndListParam theDesc, 
  
			@Description(shortDefinition="The id of the patient (one of multiple kinds of participations)")
			@OptionalParam(name="patientid")
			TokenAndListParam thePatientid, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="altid")
			TokenAndListParam theAltid, 


			@IncludeParam(allow= {
					"SecurityEvent.object.reference" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("type", theType);	
			paramMap.add("action", theAction);	
			paramMap.add("date", theDate);	
			paramMap.add("subtype", theSubtype);	
			paramMap.add("user", theUser);	
			paramMap.add("name", theName);	
			paramMap.add("address", theAddress);	
			paramMap.add("source", theSource);	
			paramMap.add("site", theSite);	
			paramMap.add("object-type", theObject_type);	
			paramMap.add("identity", theIdentity);	
			paramMap.add("reference", theReference);	
			paramMap.add("desc", theDesc);	
			paramMap.add("patientid", thePatientid);	
			paramMap.add("altid", theAltid);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
