
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class SequencingLabResourceProvider extends JpaResourceProviderDstu1<SequencingLab> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return SequencingLab.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Subject of the lab")
			@OptionalParam(name="subject", targetTypes={  Patient.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="Type of the specimen used for the lab")
			@OptionalParam(name="specimen")
			StringAndListParam theSpecimen, 
  
			@Description(shortDefinition="Date when result of the lab is uploaded")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="Organization that does the lab")
			@OptionalParam(name="organization")
			StringAndListParam theOrganization, 
  
			@Description(shortDefinition="Class of the sequencing system")
			@OptionalParam(name="system-class")
			StringAndListParam theSystem_class, 
  
			@Description(shortDefinition="Name of the sequencing system")
			@OptionalParam(name="system-name")
			StringAndListParam theSystem_name, 


			@IncludeParam(allow= {
					"SequencingLab.subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("subject", theSubject);	
			paramMap.add("specimen", theSpecimen);	
			paramMap.add("date", theDate);	
			paramMap.add("organization", theOrganization);	
			paramMap.add("system-class", theSystem_class);	
			paramMap.add("system-name", theSystem_name);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
