
package ca.uhn.fhir.jpa.rp.dstu;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu1;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu.composite.*;
import ca.uhn.fhir.model.dstu.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class SlotResourceProvider extends JpaResourceProviderDstu1<Slot> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Slot.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The type of appointments that can be booked into the slot")
			@OptionalParam(name="slottype")
			TokenAndListParam theSlottype, 
  
			@Description(shortDefinition="The Availability Resource that we are seeking a slot within")
			@OptionalParam(name="availability", targetTypes={  Availability.class   } )
			ReferenceAndListParam theAvailability, 
  
			@Description(shortDefinition="Appointment date/time.")
			@OptionalParam(name="start")
			DateRangeParam theStart, 
  
			@Description(shortDefinition="The free/busy status of the appointment")
			@OptionalParam(name="fbtype")
			TokenAndListParam theFbtype, 


			@IncludeParam(allow= {
					"Slot.availability" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("slottype", theSlottype);	
			paramMap.add("availability", theAvailability);	
			paramMap.add("start", theStart);	
			paramMap.add("fbtype", theFbtype);	
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
