
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class AllergyIntoleranceResourceProvider extends JpaResourceProviderDstu2<AllergyIntolerance> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return AllergyIntolerance.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="substance")
			TokenAndListParam theSubstance, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="criticality")
			TokenAndListParam theCriticality, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="category")
			TokenAndListParam theCategory, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="last-date")
			DateRangeParam theLast_date, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="manifestation")
			TokenAndListParam theManifestation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="onset")
			DateRangeParam theOnset, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="duration")
			QuantityAndListParam theDuration, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="severity")
			TokenAndListParam theSeverity, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="route")
			TokenAndListParam theRoute, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="recorder", targetTypes={  Practitioner.class ,   Patient.class   } )
			ReferenceAndListParam theRecorder, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reporter", targetTypes={  Patient.class ,   RelatedPerson.class ,   Practitioner.class   } )
			ReferenceAndListParam theReporter, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"AllergyIntolerance:patient" , 					"AllergyIntolerance:recorder" , 					"AllergyIntolerance:reporter" , 						"AllergyIntolerance:patient" , 					"AllergyIntolerance:recorder" , 					"AllergyIntolerance:reporter" , 						"AllergyIntolerance:patient" , 					"AllergyIntolerance:recorder" , 					"AllergyIntolerance:reporter" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("substance", theSubstance);	
			paramMap.add("status", theStatus);	
			paramMap.add("criticality", theCriticality);	
			paramMap.add("type", theType);	
			paramMap.add("category", theCategory);	
			paramMap.add("last-date", theLast_date);	
			paramMap.add("manifestation", theManifestation);	
			paramMap.add("onset", theOnset);	
			paramMap.add("duration", theDuration);	
			paramMap.add("severity", theSeverity);	
			paramMap.add("route", theRoute);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("date", theDate);	
			paramMap.add("recorder", theRecorder);	
			paramMap.add("patient", thePatient);	
			paramMap.add("reporter", theReporter);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
