
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class AppointmentResourceProvider extends JpaResourceProviderDstu2<Appointment> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Appointment.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Appointment date/time.")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="The overall status of the appointment")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="Any one of the individuals participating in the appointment")
			@OptionalParam(name="actor", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam theActor, 
  
			@Description(shortDefinition="The Participation status of the subject, or other participant on the appointment. Can be used to locate participants that have not responded to meeting requests.")
			@OptionalParam(name="partstatus")
			TokenAndListParam thePartstatus, 
  
			@Description(shortDefinition="One of the individuals of the appointment is this patient")
			@OptionalParam(name="patient", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="One of the individuals of the appointment is this practitioner")
			@OptionalParam(name="practitioner", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam thePractitioner, 
  
			@Description(shortDefinition="This location is listed in the participants of the appointment")
			@OptionalParam(name="location", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam theLocation, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Appointment:actor" , 					"Appointment:location" , 					"Appointment:patient" , 					"Appointment:practitioner" , 						"Appointment:actor" , 					"Appointment:location" , 					"Appointment:patient" , 					"Appointment:practitioner" , 						"Appointment:actor" , 					"Appointment:location" , 					"Appointment:patient" , 					"Appointment:practitioner" , 						"Appointment:actor" , 					"Appointment:location" , 					"Appointment:patient" , 					"Appointment:practitioner" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("date", theDate);	
			paramMap.add("status", theStatus);	
			paramMap.add("actor", theActor);	
			paramMap.add("partstatus", thePartstatus);	
			paramMap.add("patient", thePatient);	
			paramMap.add("practitioner", thePractitioner);	
			paramMap.add("location", theLocation);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
