
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class AppointmentResponseResourceProvider extends JpaResourceProviderDstu2<AppointmentResponse> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return AppointmentResponse.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The appointment that the response is attached to")
			@OptionalParam(name="appointment", targetTypes={  Appointment.class   } )
			ReferenceAndListParam theAppointment, 
  
			@Description(shortDefinition="The participants acceptance status for this appointment")
			@OptionalParam(name="partstatus")
			TokenAndListParam thePartstatus, 
  
			@Description(shortDefinition="The Person, Location/HealthcareService or Device that this appointment response replies for")
			@OptionalParam(name="actor", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam theActor, 
  
			@Description(shortDefinition="This Response is for this Patient")
			@OptionalParam(name="patient", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="This Response is for this Practitioner")
			@OptionalParam(name="practitioner", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam thePractitioner, 
  
			@Description(shortDefinition="This Response is for this Location")
			@OptionalParam(name="location", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Device.class ,   HealthcareService.class ,   Location.class   } )
			ReferenceAndListParam theLocation, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"AppointmentResponse:actor" , 					"AppointmentResponse:appointment" , 					"AppointmentResponse:location" , 					"AppointmentResponse:patient" , 					"AppointmentResponse:practitioner" , 						"AppointmentResponse:actor" , 					"AppointmentResponse:appointment" , 					"AppointmentResponse:location" , 					"AppointmentResponse:patient" , 					"AppointmentResponse:practitioner" , 						"AppointmentResponse:actor" , 					"AppointmentResponse:appointment" , 					"AppointmentResponse:location" , 					"AppointmentResponse:patient" , 					"AppointmentResponse:practitioner" , 						"AppointmentResponse:actor" , 					"AppointmentResponse:appointment" , 					"AppointmentResponse:location" , 					"AppointmentResponse:patient" , 					"AppointmentResponse:practitioner" , 						"AppointmentResponse:actor" , 					"AppointmentResponse:appointment" , 					"AppointmentResponse:location" , 					"AppointmentResponse:patient" , 					"AppointmentResponse:practitioner" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("appointment", theAppointment);	
			paramMap.add("partstatus", thePartstatus);	
			paramMap.add("actor", theActor);	
			paramMap.add("patient", thePatient);	
			paramMap.add("practitioner", thePractitioner);	
			paramMap.add("location", theLocation);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
