
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class CarePlanResourceProvider extends JpaResourceProviderDstu2<CarePlan> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return CarePlan.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="condition", targetTypes={  Condition.class   } )
			ReferenceAndListParam theCondition, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="participant", targetTypes={  Practitioner.class ,   RelatedPerson.class ,   Patient.class ,   Organization.class   } )
			ReferenceAndListParam theParticipant, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="activitycode")
			TokenAndListParam theActivitycode, 
  
			@Description(shortDefinition="Specified date occurs within period specified by CarePlan.activity.timingSchedule")
			@OptionalParam(name="activitydate")
			DateRangeParam theActivitydate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="activityreference", targetTypes={  Appointment.class ,   CommunicationRequest.class ,   DeviceUseRequest.class ,   DiagnosticOrder.class ,   MedicationPrescription.class ,   NutritionOrder.class ,   Order.class ,   ProcedureRequest.class ,   ProcessRequest.class ,   ReferralRequest.class ,   Supply.class ,   VisionPrescription.class   } )
			ReferenceAndListParam theActivityreference, 
  
			@Description(shortDefinition="Matches if the practitioner is listed as a performer in any of the \"simple\" activities.  (For performers of the detailed activities, chain through the activitydetail search parameter.)")
			@OptionalParam(name="performer", targetTypes={  Practitioner.class ,   Organization.class ,   RelatedPerson.class ,   Patient.class   } )
			ReferenceAndListParam thePerformer, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="goal", targetTypes={  Goal.class   } )
			ReferenceAndListParam theGoal, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"CarePlan:activityreference" , 					"CarePlan:condition" , 					"CarePlan:goal" , 					"CarePlan:participant" , 					"CarePlan:patient" , 					"CarePlan:performer" , 						"CarePlan:activityreference" , 					"CarePlan:condition" , 					"CarePlan:goal" , 					"CarePlan:participant" , 					"CarePlan:patient" , 					"CarePlan:performer" , 						"CarePlan:activityreference" , 					"CarePlan:condition" , 					"CarePlan:goal" , 					"CarePlan:participant" , 					"CarePlan:patient" , 					"CarePlan:performer" , 						"CarePlan:activityreference" , 					"CarePlan:condition" , 					"CarePlan:goal" , 					"CarePlan:participant" , 					"CarePlan:patient" , 					"CarePlan:performer" , 						"CarePlan:activityreference" , 					"CarePlan:condition" , 					"CarePlan:goal" , 					"CarePlan:participant" , 					"CarePlan:patient" , 					"CarePlan:performer" , 						"CarePlan:activityreference" , 					"CarePlan:condition" , 					"CarePlan:goal" , 					"CarePlan:participant" , 					"CarePlan:patient" , 					"CarePlan:performer" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("patient", thePatient);	
			paramMap.add("condition", theCondition);	
			paramMap.add("date", theDate);	
			paramMap.add("participant", theParticipant);	
			paramMap.add("activitycode", theActivitycode);	
			paramMap.add("activitydate", theActivitydate);	
			paramMap.add("activityreference", theActivityreference);	
			paramMap.add("performer", thePerformer);	
			paramMap.add("goal", theGoal);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
