
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ClinicalImpressionResourceProvider extends JpaResourceProviderDstu2<ClinicalImpression> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ClinicalImpression.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="previous", targetTypes={  ClinicalImpression.class   } )
			ReferenceAndListParam thePrevious, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="problem", targetTypes={  Condition.class ,   AllergyIntolerance.class   } )
			ReferenceAndListParam theProblem, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="trigger", targetTypes={  } )
			ReferenceAndListParam theTrigger, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="trigger-code")
			TokenAndListParam theTrigger_code, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="investigation", targetTypes={  Observation.class ,   QuestionnaireAnswers.class ,   FamilyMemberHistory.class ,   DiagnosticReport.class   } )
			ReferenceAndListParam theInvestigation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="finding")
			TokenAndListParam theFinding, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="resolved")
			TokenAndListParam theResolved, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="ruledout")
			TokenAndListParam theRuledout, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="plan", targetTypes={  CarePlan.class ,   Appointment.class ,   CommunicationRequest.class ,   DeviceUseRequest.class ,   DiagnosticOrder.class ,   MedicationPrescription.class ,   NutritionOrder.class ,   Order.class ,   ProcedureRequest.class ,   ProcessRequest.class ,   ReferralRequest.class ,   Supply.class ,   VisionPrescription.class   } )
			ReferenceAndListParam thePlan, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="action", targetTypes={  ReferralRequest.class ,   ProcedureRequest.class ,   Procedure.class ,   MedicationPrescription.class ,   DiagnosticOrder.class ,   NutritionOrder.class ,   Supply.class ,   Appointment.class   } )
			ReferenceAndListParam theAction, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="assessor", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theAssessor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" , 						"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" , 						"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" , 						"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" , 						"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" , 						"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" , 						"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" , 						"ClinicalImpression:action" , 					"ClinicalImpression:assessor" , 					"ClinicalImpression:investigation" , 					"ClinicalImpression:patient" , 					"ClinicalImpression:plan" , 					"ClinicalImpression:previous" , 					"ClinicalImpression:problem" , 					"ClinicalImpression:trigger" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("previous", thePrevious);	
			paramMap.add("problem", theProblem);	
			paramMap.add("trigger", theTrigger);	
			paramMap.add("trigger-code", theTrigger_code);	
			paramMap.add("investigation", theInvestigation);	
			paramMap.add("finding", theFinding);	
			paramMap.add("resolved", theResolved);	
			paramMap.add("ruledout", theRuledout);	
			paramMap.add("plan", thePlan);	
			paramMap.add("action", theAction);	
			paramMap.add("patient", thePatient);	
			paramMap.add("assessor", theAssessor);	
			paramMap.add("date", theDate);	
			paramMap.add("status", theStatus);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
