
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class CompositionResourceProvider extends JpaResourceProviderDstu2<Composition> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Composition.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="class")
			TokenAndListParam theClass, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="author", targetTypes={  Practitioner.class ,   Device.class ,   Patient.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theAuthor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="attester", targetTypes={  Patient.class ,   Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam theAttester, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="context")
			TokenAndListParam theContext, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="section", targetTypes={  ListResource.class   } )
			ReferenceAndListParam theSection, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="title")
			StringAndListParam theTitle, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="confidentiality")
			TokenAndListParam theConfidentiality, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="period")
			DateRangeParam thePeriod, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="section-code")
			TokenAndListParam theSection_code, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="encounter", targetTypes={  Encounter.class   } )
			ReferenceAndListParam theEncounter, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Composition:attester" , 					"Composition:author" , 					"Composition:encounter" , 					"Composition:patient" , 					"Composition:section" , 					"Composition:subject" , 						"Composition:attester" , 					"Composition:author" , 					"Composition:encounter" , 					"Composition:patient" , 					"Composition:section" , 					"Composition:subject" , 						"Composition:attester" , 					"Composition:author" , 					"Composition:encounter" , 					"Composition:patient" , 					"Composition:section" , 					"Composition:subject" , 						"Composition:attester" , 					"Composition:author" , 					"Composition:encounter" , 					"Composition:patient" , 					"Composition:section" , 					"Composition:subject" , 						"Composition:attester" , 					"Composition:author" , 					"Composition:encounter" , 					"Composition:patient" , 					"Composition:section" , 					"Composition:subject" , 						"Composition:attester" , 					"Composition:author" , 					"Composition:encounter" , 					"Composition:patient" , 					"Composition:section" , 					"Composition:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("type", theType);	
			paramMap.add("class", theClass);	
			paramMap.add("date", theDate);	
			paramMap.add("subject", theSubject);	
			paramMap.add("author", theAuthor);	
			paramMap.add("attester", theAttester);	
			paramMap.add("context", theContext);	
			paramMap.add("section", theSection);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("title", theTitle);	
			paramMap.add("status", theStatus);	
			paramMap.add("confidentiality", theConfidentiality);	
			paramMap.add("period", thePeriod);	
			paramMap.add("section-code", theSection_code);	
			paramMap.add("patient", thePatient);	
			paramMap.add("encounter", theEncounter);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
