
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ConceptMapResourceProvider extends JpaResourceProviderDstu2<ConceptMap> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ConceptMap.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The url of the concept map")
			@OptionalParam(name="url")
			UriAndListParam theUrl, 
  
			@Description(shortDefinition="Additional identifier for the concept map")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The version identifier of the concept map")
			@OptionalParam(name="version")
			TokenAndListParam theVersion, 
  
			@Description(shortDefinition="Name of the concept map")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="Name of the publisher of the concept map")
			@OptionalParam(name="publisher")
			StringAndListParam thePublisher, 
  
			@Description(shortDefinition="Text search in the description of the concept map")
			@OptionalParam(name="description")
			StringAndListParam theDescription, 
  
			@Description(shortDefinition="Status of the concept map")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="The concept map publication date")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="The system for any concepts mapped by this concept map")
			@OptionalParam(name="source", targetTypes={  ValueSet.class ,   StructureDefinition.class   } )
			ReferenceAndListParam theSource, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="target", targetTypes={  ValueSet.class ,   StructureDefinition.class   } )
			ReferenceAndListParam theTarget, 
  
			@Description(shortDefinition="The system for any destination concepts mapped by this map")
			@OptionalParam(name="system")
			UriAndListParam theSystem, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dependson")
			UriAndListParam theDependson, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="product")
			UriAndListParam theProduct, 
  
			@Description(shortDefinition="A use context assigned to the concept map")
			@OptionalParam(name="context")
			TokenAndListParam theContext, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"ConceptMap:source" , 					"ConceptMap:target" , 						"ConceptMap:source" , 					"ConceptMap:target" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("url", theUrl);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("version", theVersion);	
			paramMap.add("name", theName);	
			paramMap.add("publisher", thePublisher);	
			paramMap.add("description", theDescription);	
			paramMap.add("status", theStatus);	
			paramMap.add("date", theDate);	
			paramMap.add("source", theSource);	
			paramMap.add("target", theTarget);	
			paramMap.add("system", theSystem);	
			paramMap.add("dependson", theDependson);	
			paramMap.add("product", theProduct);	
			paramMap.add("context", theContext);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
