
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ConditionResourceProvider extends JpaResourceProviderDstu2<Condition> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Condition.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Code for the condition")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="The clinical status of the condition")
			@OptionalParam(name="clinicalstatus")
			TokenAndListParam theClinicalstatus, 
  
			@Description(shortDefinition="The severity of the condition")
			@OptionalParam(name="severity")
			TokenAndListParam theSeverity, 
  
			@Description(shortDefinition="The category of the condition")
			@OptionalParam(name="category")
			TokenAndListParam theCategory, 
  
			@Description(shortDefinition="Date related onsets (dateTime and Period)")
			@OptionalParam(name="onset")
			DateRangeParam theOnset, 
  
			@Description(shortDefinition="Other onsets (boolean, age, range, string)")
			@OptionalParam(name="onset-info")
			StringAndListParam theOnset_info, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="encounter", targetTypes={  Encounter.class   } )
			ReferenceAndListParam theEncounter, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="asserter", targetTypes={  Practitioner.class ,   Patient.class   } )
			ReferenceAndListParam theAsserter, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date-asserted")
			DateRangeParam theDate_asserted, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="evidence")
			TokenAndListParam theEvidence, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="location")
			TokenAndListParam theLocation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="stage")
			TokenAndListParam theStage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dueto-code")
			TokenAndListParam theDueto_code, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dueto-item", targetTypes={  Condition.class ,   Procedure.class ,   MedicationAdministration.class ,   Immunization.class ,   MedicationStatement.class   } )
			ReferenceAndListParam theDueto_item, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="following-code")
			TokenAndListParam theFollowing_code, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="following-item", targetTypes={  Condition.class ,   Procedure.class ,   MedicationAdministration.class ,   Immunization.class ,   MedicationStatement.class   } )
			ReferenceAndListParam theFollowing_item, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Condition:asserter" , 					"Condition:dueto-item" , 					"Condition:encounter" , 					"Condition:following-item" , 					"Condition:patient" , 					"Condition:subject" , 						"Condition:asserter" , 					"Condition:dueto-item" , 					"Condition:encounter" , 					"Condition:following-item" , 					"Condition:patient" , 					"Condition:subject" , 						"Condition:asserter" , 					"Condition:dueto-item" , 					"Condition:encounter" , 					"Condition:following-item" , 					"Condition:patient" , 					"Condition:subject" , 						"Condition:asserter" , 					"Condition:dueto-item" , 					"Condition:encounter" , 					"Condition:following-item" , 					"Condition:patient" , 					"Condition:subject" , 						"Condition:asserter" , 					"Condition:dueto-item" , 					"Condition:encounter" , 					"Condition:following-item" , 					"Condition:patient" , 					"Condition:subject" , 						"Condition:asserter" , 					"Condition:dueto-item" , 					"Condition:encounter" , 					"Condition:following-item" , 					"Condition:patient" , 					"Condition:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("code", theCode);	
			paramMap.add("clinicalstatus", theClinicalstatus);	
			paramMap.add("severity", theSeverity);	
			paramMap.add("category", theCategory);	
			paramMap.add("onset", theOnset);	
			paramMap.add("onset-info", theOnset_info);	
			paramMap.add("encounter", theEncounter);	
			paramMap.add("asserter", theAsserter);	
			paramMap.add("date-asserted", theDate_asserted);	
			paramMap.add("evidence", theEvidence);	
			paramMap.add("location", theLocation);	
			paramMap.add("stage", theStage);	
			paramMap.add("patient", thePatient);	
			paramMap.add("subject", theSubject);	
			paramMap.add("dueto-code", theDueto_code);	
			paramMap.add("dueto-item", theDueto_item);	
			paramMap.add("following-code", theFollowing_code);	
			paramMap.add("following-item", theFollowing_item);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
