
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ContractResourceProvider extends JpaResourceProviderDstu2<Contract> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Contract.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The identity of the target of the contract")
			@OptionalParam(name="subject", targetTypes={  } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="The identity of the target of the contract (if a patient)")
			@OptionalParam(name="patient", targetTypes={  } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="The identity of the contract")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="actor", targetTypes={  Contract.class ,   Device.class ,   Group.class ,   Location.class ,   Organization.class ,   Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Substance.class ,   Supply.class   } )
			ReferenceAndListParam theActor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="signer", targetTypes={  Organization.class ,   Patient.class ,   Practitioner.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theSigner, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Contract:actor" , 					"Contract:patient" , 					"Contract:signer" , 					"Contract:subject" , 						"Contract:actor" , 					"Contract:patient" , 					"Contract:signer" , 					"Contract:subject" , 						"Contract:actor" , 					"Contract:patient" , 					"Contract:signer" , 					"Contract:subject" , 						"Contract:actor" , 					"Contract:patient" , 					"Contract:signer" , 					"Contract:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("subject", theSubject);	
			paramMap.add("patient", thePatient);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("actor", theActor);	
			paramMap.add("signer", theSigner);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
