
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class DeviceMetricResourceProvider extends JpaResourceProviderDstu2<DeviceMetric> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return DeviceMetric.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The parent DeviceMetric resource")
			@OptionalParam(name="parent", targetTypes={  DeviceComponent.class   } )
			ReferenceAndListParam theParent, 
  
			@Description(shortDefinition="The component type")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="The device resource")
			@OptionalParam(name="source", targetTypes={  Device.class   } )
			ReferenceAndListParam theSource, 
  
			@Description(shortDefinition="The category of the metric")
			@OptionalParam(name="category")
			TokenAndListParam theCategory, 
  
			@Description(shortDefinition="The identifier of the metric")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"DeviceMetric:parent" , 					"DeviceMetric:source" , 						"DeviceMetric:parent" , 					"DeviceMetric:source" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("parent", theParent);	
			paramMap.add("type", theType);	
			paramMap.add("source", theSource);	
			paramMap.add("category", theCategory);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
