
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class DiagnosticReportResourceProvider extends JpaResourceProviderDstu2<DiagnosticReport> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return DiagnosticReport.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The status of the report")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="When the report was issued")
			@OptionalParam(name="issued")
			DateRangeParam theIssued, 
  
			@Description(shortDefinition="The subject of the report")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Group.class ,   Device.class ,   Location.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="Who was the source of the report (organization)")
			@OptionalParam(name="performer", targetTypes={  Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam thePerformer, 
  
			@Description(shortDefinition="An identifier for the report")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="Which diagnostic discipline/department created the report")
			@OptionalParam(name="service")
			TokenAndListParam theService, 
  
			@Description(shortDefinition="The clinically relevant time of the report")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="The specimen details")
			@OptionalParam(name="specimen", targetTypes={  Specimen.class   } )
			ReferenceAndListParam theSpecimen, 
  
			@Description(shortDefinition="The name of the report (e.g. the code for the report as a whole, as opposed to codes for the atomic results, which are the names on the observation resource referred to from the result)")
			@OptionalParam(name="name")
			TokenAndListParam theName, 
  
			@Description(shortDefinition="Link to an atomic result (observation resource)")
			@OptionalParam(name="result", targetTypes={  Observation.class   } )
			ReferenceAndListParam theResult, 
  
			@Description(shortDefinition="A coded diagnosis on the report")
			@OptionalParam(name="diagnosis")
			TokenAndListParam theDiagnosis, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="image", targetTypes={  Media.class   } )
			ReferenceAndListParam theImage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="request", targetTypes={  DiagnosticOrder.class   } )
			ReferenceAndListParam theRequest, 
  
			@Description(shortDefinition="The subject of the report if a patient")
			@OptionalParam(name="patient", targetTypes={  Patient.class ,   Group.class ,   Device.class ,   Location.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="The Encounter when the order was made")
			@OptionalParam(name="encounter", targetTypes={  Encounter.class   } )
			ReferenceAndListParam theEncounter, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" , 						"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" , 						"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" , 						"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" , 						"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" , 						"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" , 						"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" , 						"DiagnosticReport:encounter" , 					"DiagnosticReport:image" , 					"DiagnosticReport:patient" , 					"DiagnosticReport:performer" , 					"DiagnosticReport:request" , 					"DiagnosticReport:result" , 					"DiagnosticReport:specimen" , 					"DiagnosticReport:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("status", theStatus);	
			paramMap.add("issued", theIssued);	
			paramMap.add("subject", theSubject);	
			paramMap.add("performer", thePerformer);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("service", theService);	
			paramMap.add("date", theDate);	
			paramMap.add("specimen", theSpecimen);	
			paramMap.add("name", theName);	
			paramMap.add("result", theResult);	
			paramMap.add("diagnosis", theDiagnosis);	
			paramMap.add("image", theImage);	
			paramMap.add("request", theRequest);	
			paramMap.add("patient", thePatient);	
			paramMap.add("encounter", theEncounter);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
