
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class DocumentManifestResourceProvider extends JpaResourceProviderDstu2<DocumentManifest> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return DocumentManifest.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Practitioner.class ,   Group.class ,   Device.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="recipient", targetTypes={  Patient.class ,   Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam theRecipient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="author", targetTypes={  Practitioner.class ,   Organization.class ,   Device.class ,   Patient.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theAuthor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="created")
			DateRangeParam theCreated, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="description")
			StringAndListParam theDescription, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="contentref", targetTypes={  } )
			ReferenceAndListParam theContentref, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class ,   Practitioner.class ,   Group.class ,   Device.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source")
			UriAndListParam theSource, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="relatedid")
			TokenAndListParam theRelatedid, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="relatedref", targetTypes={  } )
			ReferenceAndListParam theRelatedref, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"DocumentManifest:author" , 					"DocumentManifest:contentref" , 					"DocumentManifest:patient" , 					"DocumentManifest:recipient" , 					"DocumentManifest:relatedref" , 					"DocumentManifest:subject" , 						"DocumentManifest:author" , 					"DocumentManifest:contentref" , 					"DocumentManifest:patient" , 					"DocumentManifest:recipient" , 					"DocumentManifest:relatedref" , 					"DocumentManifest:subject" , 						"DocumentManifest:author" , 					"DocumentManifest:contentref" , 					"DocumentManifest:patient" , 					"DocumentManifest:recipient" , 					"DocumentManifest:relatedref" , 					"DocumentManifest:subject" , 						"DocumentManifest:author" , 					"DocumentManifest:contentref" , 					"DocumentManifest:patient" , 					"DocumentManifest:recipient" , 					"DocumentManifest:relatedref" , 					"DocumentManifest:subject" , 						"DocumentManifest:author" , 					"DocumentManifest:contentref" , 					"DocumentManifest:patient" , 					"DocumentManifest:recipient" , 					"DocumentManifest:relatedref" , 					"DocumentManifest:subject" , 						"DocumentManifest:author" , 					"DocumentManifest:contentref" , 					"DocumentManifest:patient" , 					"DocumentManifest:recipient" , 					"DocumentManifest:relatedref" , 					"DocumentManifest:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("subject", theSubject);	
			paramMap.add("type", theType);	
			paramMap.add("recipient", theRecipient);	
			paramMap.add("author", theAuthor);	
			paramMap.add("created", theCreated);	
			paramMap.add("status", theStatus);	
			paramMap.add("description", theDescription);	
			paramMap.add("contentref", theContentref);	
			paramMap.add("patient", thePatient);	
			paramMap.add("source", theSource);	
			paramMap.add("relatedid", theRelatedid);	
			paramMap.add("relatedref", theRelatedref);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
