
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class EncounterResourceProvider extends JpaResourceProviderDstu2<Encounter> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Encounter.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="A date within the period the Encounter lasted")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="fulfills", targetTypes={  Appointment.class   } )
			ReferenceAndListParam theFulfills, 
  
			@Description(shortDefinition="Length of encounter in days")
			@OptionalParam(name="length")
			NumberAndListParam theLength, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reason")
			TokenAndListParam theReason, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="indication", targetTypes={  } )
			ReferenceAndListParam theIndication, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="location", targetTypes={  Location.class   } )
			ReferenceAndListParam theLocation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="location-period")
			DateRangeParam theLocation_period, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="special-arrangement")
			TokenAndListParam theSpecial_arrangement, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="part-of", targetTypes={  Encounter.class   } )
			ReferenceAndListParam thePart_of, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="participant", targetTypes={  Practitioner.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theParticipant, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="participant-type")
			TokenAndListParam theParticipant_type, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="episodeofcare", targetTypes={  EpisodeOfCare.class   } )
			ReferenceAndListParam theEpisodeofcare, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="incomingreferral", targetTypes={  ReferralRequest.class   } )
			ReferenceAndListParam theIncomingreferral, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="practitioner", targetTypes={  Practitioner.class ,   RelatedPerson.class   } )
			ReferenceAndListParam thePractitioner, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" , 						"Encounter:episodeofcare" , 					"Encounter:fulfills" , 					"Encounter:incomingreferral" , 					"Encounter:indication" , 					"Encounter:location" , 					"Encounter:part-of" , 					"Encounter:participant" , 					"Encounter:patient" , 					"Encounter:practitioner" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("status", theStatus);	
			paramMap.add("date", theDate);	
			paramMap.add("patient", thePatient);	
			paramMap.add("fulfills", theFulfills);	
			paramMap.add("length", theLength);	
			paramMap.add("reason", theReason);	
			paramMap.add("indication", theIndication);	
			paramMap.add("location", theLocation);	
			paramMap.add("location-period", theLocation_period);	
			paramMap.add("type", theType);	
			paramMap.add("special-arrangement", theSpecial_arrangement);	
			paramMap.add("part-of", thePart_of);	
			paramMap.add("participant", theParticipant);	
			paramMap.add("participant-type", theParticipant_type);	
			paramMap.add("episodeofcare", theEpisodeofcare);	
			paramMap.add("incomingreferral", theIncomingreferral);	
			paramMap.add("practitioner", thePractitioner);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}



	@Operation(name="everything", idempotent=true)
	public ca.uhn.fhir.rest.server.IBundleProvider everything(
			javax.servlet.http.HttpServletRequest theServletRequest, 
			@IdParam ca.uhn.fhir.model.primitive.IdDt theId, 
			
			@Description(formalDefinition="Results from this method are returned across multiple pages. This parameter controls the size of those pages.")
			@OperationParam(name="_count") ca.uhn.fhir.model.primitive.UnsignedIntDt theCount
	){

		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			if (theCount != null) {
				paramMap.setCount(theCount.getValue());
			}

			paramMap.setRevIncludes(Collections.singleton(new Include("*")));
			paramMap.setIncludes(Collections.singleton(new Include("*")));
			paramMap.add("_id", new StringParam(theId.getIdPart()));		
			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}

	}

}
