
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class EpisodeOfCareResourceProvider extends JpaResourceProviderDstu2<EpisodeOfCare> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return EpisodeOfCare.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The current status of the Episode of Care as provided (does not check the status history collection)")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="The organization that has assumed the specific responsibilities of this EpisodeOfCare")
			@OptionalParam(name="organization", targetTypes={  Organization.class   } )
			ReferenceAndListParam theOrganization, 
  
			@Description(shortDefinition="The provided date search value falls within the episode of care's period")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="condition", targetTypes={  Condition.class   } )
			ReferenceAndListParam theCondition, 
  
			@Description(shortDefinition="Incoming Referral Request")
			@OptionalParam(name="incomingreferral", targetTypes={  ReferralRequest.class   } )
			ReferenceAndListParam theIncomingreferral, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="care-manager", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theCare_manager, 
  
			@Description(shortDefinition="A Practitioner or Organization allocated to the care team for this EpisodeOfCare")
			@OptionalParam(name="team-member", targetTypes={  Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam theTeam_member, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"EpisodeOfCare:care-manager" , 					"EpisodeOfCare:condition" , 					"EpisodeOfCare:incomingreferral" , 					"EpisodeOfCare:organization" , 					"EpisodeOfCare:patient" , 					"EpisodeOfCare:team-member" , 						"EpisodeOfCare:care-manager" , 					"EpisodeOfCare:condition" , 					"EpisodeOfCare:incomingreferral" , 					"EpisodeOfCare:organization" , 					"EpisodeOfCare:patient" , 					"EpisodeOfCare:team-member" , 						"EpisodeOfCare:care-manager" , 					"EpisodeOfCare:condition" , 					"EpisodeOfCare:incomingreferral" , 					"EpisodeOfCare:organization" , 					"EpisodeOfCare:patient" , 					"EpisodeOfCare:team-member" , 						"EpisodeOfCare:care-manager" , 					"EpisodeOfCare:condition" , 					"EpisodeOfCare:incomingreferral" , 					"EpisodeOfCare:organization" , 					"EpisodeOfCare:patient" , 					"EpisodeOfCare:team-member" , 						"EpisodeOfCare:care-manager" , 					"EpisodeOfCare:condition" , 					"EpisodeOfCare:incomingreferral" , 					"EpisodeOfCare:organization" , 					"EpisodeOfCare:patient" , 					"EpisodeOfCare:team-member" , 						"EpisodeOfCare:care-manager" , 					"EpisodeOfCare:condition" , 					"EpisodeOfCare:incomingreferral" , 					"EpisodeOfCare:organization" , 					"EpisodeOfCare:patient" , 					"EpisodeOfCare:team-member" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("patient", thePatient);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("status", theStatus);	
			paramMap.add("organization", theOrganization);	
			paramMap.add("date", theDate);	
			paramMap.add("type", theType);	
			paramMap.add("condition", theCondition);	
			paramMap.add("incomingreferral", theIncomingreferral);	
			paramMap.add("care-manager", theCare_manager);	
			paramMap.add("team-member", theTeam_member);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
