
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class HealthcareServiceResourceProvider extends JpaResourceProviderDstu2<HealthcareService> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return HealthcareService.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Service Category of the Healthcare Service")
			@OptionalParam(name="servicecategory")
			TokenAndListParam theServicecategory, 
  
			@Description(shortDefinition="The type of service provided by this healthcare service")
			@OptionalParam(name="servicetype")
			TokenAndListParam theServicetype, 
  
			@Description(shortDefinition="A portion of the Healthcare service name")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="The location of the Healthcare Service")
			@OptionalParam(name="location", targetTypes={  Location.class   } )
			ReferenceAndListParam theLocation, 
  
			@Description(shortDefinition="The organization that provides this Healthcare Service")
			@OptionalParam(name="organization", targetTypes={  Organization.class   } )
			ReferenceAndListParam theOrganization, 
  
			@Description(shortDefinition="One of the Program Names serviced by this HealthcareService")
			@OptionalParam(name="programname")
			StringAndListParam theProgramname, 
  
			@Description(shortDefinition="One of the HealthcareService's characteristics")
			@OptionalParam(name="characteristic")
			TokenAndListParam theCharacteristic, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"HealthcareService:location" , 					"HealthcareService:organization" , 						"HealthcareService:location" , 					"HealthcareService:organization" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("servicecategory", theServicecategory);	
			paramMap.add("servicetype", theServicetype);	
			paramMap.add("name", theName);	
			paramMap.add("location", theLocation);	
			paramMap.add("organization", theOrganization);	
			paramMap.add("programname", theProgramname);	
			paramMap.add("characteristic", theCharacteristic);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
