
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ImagingObjectSelectionResourceProvider extends JpaResourceProviderDstu2<ImagingObjectSelection> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ImagingObjectSelection.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="UID of key DICOM object selection")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="Title of key DICOM object selection")
			@OptionalParam(name="title")
			TokenAndListParam theTitle, 
  
			@Description(shortDefinition="Author of key DICOM object selection")
			@OptionalParam(name="author", targetTypes={  Practitioner.class ,   Device.class ,   Organization.class ,   Patient.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theAuthor, 
  
			@Description(shortDefinition="Time of key DICOM object selection authoring")
			@OptionalParam(name="authoring-time")
			DateRangeParam theAuthoring_time, 
  
			@Description(shortDefinition="Subject of key DICOM object selection")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="Study selected in key DICOM object selection")
			@OptionalParam(name="selected-study")
			TokenAndListParam theSelected_study, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"ImagingObjectSelection:author" , 					"ImagingObjectSelection:patient" , 						"ImagingObjectSelection:author" , 					"ImagingObjectSelection:patient" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("title", theTitle);	
			paramMap.add("author", theAuthor);	
			paramMap.add("authoring-time", theAuthoring_time);	
			paramMap.add("patient", thePatient);	
			paramMap.add("selected-study", theSelected_study);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
