
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ImagingStudyResourceProvider extends JpaResourceProviderDstu2<ImagingStudy> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ImagingStudy.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Who the study is about")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="When the study was started")
			@OptionalParam(name="started")
			DateRangeParam theStarted, 
  
			@Description(shortDefinition="The accession id for the image")
			@OptionalParam(name="accession")
			TokenAndListParam theAccession, 
  
			@Description(shortDefinition="The study id for the image")
			@OptionalParam(name="study")
			TokenAndListParam theStudy, 
  
			@Description(shortDefinition="The series id for the image")
			@OptionalParam(name="series")
			TokenAndListParam theSeries, 
  
			@Description(shortDefinition="The modality of the image")
			@OptionalParam(name="modality")
			TokenAndListParam theModality, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="bodysite")
			TokenAndListParam theBodysite, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="uid")
			TokenAndListParam theUid, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dicom-class")
			TokenAndListParam theDicom_class, 
  
			@Description(shortDefinition="The order for the image")
			@OptionalParam(name="order", targetTypes={  DiagnosticOrder.class   } )
			ReferenceAndListParam theOrder, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"ImagingStudy:order" , 					"ImagingStudy:patient" , 						"ImagingStudy:order" , 					"ImagingStudy:patient" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("patient", thePatient);	
			paramMap.add("started", theStarted);	
			paramMap.add("accession", theAccession);	
			paramMap.add("study", theStudy);	
			paramMap.add("series", theSeries);	
			paramMap.add("modality", theModality);	
			paramMap.add("bodysite", theBodysite);	
			paramMap.add("uid", theUid);	
			paramMap.add("dicom-class", theDicom_class);	
			paramMap.add("order", theOrder);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
