
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ImmunizationRecommendationResourceProvider extends JpaResourceProviderDstu2<ImmunizationRecommendation> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ImmunizationRecommendation.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="vaccine-type")
			TokenAndListParam theVaccine_type, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dose-number")
			NumberAndListParam theDose_number, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dose-sequence")
			TokenAndListParam theDose_sequence, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="support", targetTypes={  Immunization.class   } )
			ReferenceAndListParam theSupport, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="information", targetTypes={  Observation.class ,   AllergyIntolerance.class   } )
			ReferenceAndListParam theInformation, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"ImmunizationRecommendation:information" , 					"ImmunizationRecommendation:patient" , 					"ImmunizationRecommendation:subject" , 					"ImmunizationRecommendation:support" , 						"ImmunizationRecommendation:information" , 					"ImmunizationRecommendation:patient" , 					"ImmunizationRecommendation:subject" , 					"ImmunizationRecommendation:support" , 						"ImmunizationRecommendation:information" , 					"ImmunizationRecommendation:patient" , 					"ImmunizationRecommendation:subject" , 					"ImmunizationRecommendation:support" , 						"ImmunizationRecommendation:information" , 					"ImmunizationRecommendation:patient" , 					"ImmunizationRecommendation:subject" , 					"ImmunizationRecommendation:support" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("subject", theSubject);	
			paramMap.add("vaccine-type", theVaccine_type);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("date", theDate);	
			paramMap.add("dose-number", theDose_number);	
			paramMap.add("status", theStatus);	
			paramMap.add("dose-sequence", theDose_sequence);	
			paramMap.add("support", theSupport);	
			paramMap.add("information", theInformation);	
			paramMap.add("patient", thePatient);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
