
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ImmunizationResourceProvider extends JpaResourceProviderDstu2<Immunization> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Immunization.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Vaccination  (non)-Administration Date")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dose-sequence")
			NumberAndListParam theDose_sequence, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The service delivery location or facility in which the vaccine was / was to be administered")
			@OptionalParam(name="location", targetTypes={  Location.class   } )
			ReferenceAndListParam theLocation, 
  
			@Description(shortDefinition="Vaccine Lot Number")
			@OptionalParam(name="lot-number")
			StringAndListParam theLot_number, 
  
			@Description(shortDefinition="Vaccine Manufacturer")
			@OptionalParam(name="manufacturer", targetTypes={  Organization.class   } )
			ReferenceAndListParam theManufacturer, 
  
			@Description(shortDefinition="The practitioner who administered the vaccination")
			@OptionalParam(name="performer", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam thePerformer, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reaction", targetTypes={  Observation.class   } )
			ReferenceAndListParam theReaction, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reaction-date")
			DateRangeParam theReaction_date, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="reason")
			TokenAndListParam theReason, 
  
			@Description(shortDefinition="Explanation of reason vaccination was not administered")
			@OptionalParam(name="reason-not-given")
			TokenAndListParam theReason_not_given, 
  
			@Description(shortDefinition="Administrations which were not given")
			@OptionalParam(name="notgiven")
			TokenAndListParam theNotgiven, 
  
			@Description(shortDefinition="The practitioner who ordered the vaccination")
			@OptionalParam(name="requester", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theRequester, 
  
			@Description(shortDefinition="The patient for the vaccination record")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="Vaccine Product Type Administered")
			@OptionalParam(name="vaccine-type")
			TokenAndListParam theVaccine_type, 
  
			@Description(shortDefinition="The patient for the vaccination record")
			@OptionalParam(name="subject", targetTypes={  Patient.class   } )
			ReferenceAndListParam theSubject, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Immunization:location" , 					"Immunization:manufacturer" , 					"Immunization:patient" , 					"Immunization:performer" , 					"Immunization:reaction" , 					"Immunization:requester" , 					"Immunization:subject" , 						"Immunization:location" , 					"Immunization:manufacturer" , 					"Immunization:patient" , 					"Immunization:performer" , 					"Immunization:reaction" , 					"Immunization:requester" , 					"Immunization:subject" , 						"Immunization:location" , 					"Immunization:manufacturer" , 					"Immunization:patient" , 					"Immunization:performer" , 					"Immunization:reaction" , 					"Immunization:requester" , 					"Immunization:subject" , 						"Immunization:location" , 					"Immunization:manufacturer" , 					"Immunization:patient" , 					"Immunization:performer" , 					"Immunization:reaction" , 					"Immunization:requester" , 					"Immunization:subject" , 						"Immunization:location" , 					"Immunization:manufacturer" , 					"Immunization:patient" , 					"Immunization:performer" , 					"Immunization:reaction" , 					"Immunization:requester" , 					"Immunization:subject" , 						"Immunization:location" , 					"Immunization:manufacturer" , 					"Immunization:patient" , 					"Immunization:performer" , 					"Immunization:reaction" , 					"Immunization:requester" , 					"Immunization:subject" , 						"Immunization:location" , 					"Immunization:manufacturer" , 					"Immunization:patient" , 					"Immunization:performer" , 					"Immunization:reaction" , 					"Immunization:requester" , 					"Immunization:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("date", theDate);	
			paramMap.add("dose-sequence", theDose_sequence);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("location", theLocation);	
			paramMap.add("lot-number", theLot_number);	
			paramMap.add("manufacturer", theManufacturer);	
			paramMap.add("performer", thePerformer);	
			paramMap.add("reaction", theReaction);	
			paramMap.add("reaction-date", theReaction_date);	
			paramMap.add("reason", theReason);	
			paramMap.add("reason-not-given", theReason_not_given);	
			paramMap.add("notgiven", theNotgiven);	
			paramMap.add("requester", theRequester);	
			paramMap.add("patient", thePatient);	
			paramMap.add("vaccine-type", theVaccine_type);	
			paramMap.add("subject", theSubject);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
