
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ListResourceResourceProvider extends JpaResourceProviderDstu2<ListResource> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ListResource.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source", targetTypes={  Practitioner.class ,   Patient.class ,   Device.class   } )
			ReferenceAndListParam theSource, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="item", targetTypes={  } )
			ReferenceAndListParam theItem, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="empty-reason")
			TokenAndListParam theEmpty_reason, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Group.class ,   Device.class ,   Location.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class ,   Group.class ,   Device.class ,   Location.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="title")
			StringAndListParam theTitle, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="notes")
			StringAndListParam theNotes, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"List:item" , 					"List:patient" , 					"List:source" , 					"List:subject" , 						"List:item" , 					"List:patient" , 					"List:source" , 					"List:subject" , 						"List:item" , 					"List:patient" , 					"List:source" , 					"List:subject" , 						"List:item" , 					"List:patient" , 					"List:source" , 					"List:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("source", theSource);	
			paramMap.add("item", theItem);	
			paramMap.add("empty-reason", theEmpty_reason);	
			paramMap.add("date", theDate);	
			paramMap.add("code", theCode);	
			paramMap.add("subject", theSubject);	
			paramMap.add("patient", thePatient);	
			paramMap.add("status", theStatus);	
			paramMap.add("title", theTitle);	
			paramMap.add("notes", theNotes);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
