
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class LocationResourceProvider extends JpaResourceProviderDstu2<Location> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Location.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="A (portion of the) name of the location")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="A code for the type of location")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="A (part of the) address of the location")
			@OptionalParam(name="address")
			StringAndListParam theAddress, 
  
			@Description(shortDefinition="Searches for locations with a specific kind of status")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="The location of which this location is a part")
			@OptionalParam(name="partof", targetTypes={  Location.class   } )
			ReferenceAndListParam thePartof, 
  
			@Description(shortDefinition="The coordinates expressed as [lat],[long] (using the WGS84 datum, see notes) to find locations near to (servers may search using a square rather than a circle for efficiency)")
			@OptionalParam(name="near")
			TokenAndListParam theNear, 
  
			@Description(shortDefinition="A distance quantity to limit the near search to locations within a specific distance")
			@OptionalParam(name="near-distance")
			TokenAndListParam theNear_distance, 
  
			@Description(shortDefinition="Searches for locations that are managed by the provided organization")
			@OptionalParam(name="organization", targetTypes={  Organization.class   } )
			ReferenceAndListParam theOrganization, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Location:organization" , 					"Location:partof" , 						"Location:organization" , 					"Location:partof" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("name", theName);	
			paramMap.add("type", theType);	
			paramMap.add("address", theAddress);	
			paramMap.add("status", theStatus);	
			paramMap.add("partof", thePartof);	
			paramMap.add("near", theNear);	
			paramMap.add("near-distance", theNear_distance);	
			paramMap.add("organization", theOrganization);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
