
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class MedicationResourceProvider extends JpaResourceProviderDstu2<Medication> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Medication.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="manufacturer", targetTypes={  Organization.class   } )
			ReferenceAndListParam theManufacturer, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="form")
			TokenAndListParam theForm, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="ingredient", targetTypes={  Substance.class ,   Medication.class   } )
			ReferenceAndListParam theIngredient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="container")
			TokenAndListParam theContainer, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="content", targetTypes={  Medication.class   } )
			ReferenceAndListParam theContent, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Medication:content" , 					"Medication:ingredient" , 					"Medication:manufacturer" , 						"Medication:content" , 					"Medication:ingredient" , 					"Medication:manufacturer" , 						"Medication:content" , 					"Medication:ingredient" , 					"Medication:manufacturer" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("code", theCode);	
			paramMap.add("name", theName);	
			paramMap.add("manufacturer", theManufacturer);	
			paramMap.add("form", theForm);	
			paramMap.add("ingredient", theIngredient);	
			paramMap.add("container", theContainer);	
			paramMap.add("content", theContent);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
