
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class MedicationStatementResourceProvider extends JpaResourceProviderDstu2<MedicationStatement> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return MedicationStatement.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="Return statements with this external identity")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="Code for medicine or text in medicine name")
			@OptionalParam(name="medication", targetTypes={  Medication.class   } )
			ReferenceAndListParam theMedication, 
  
			@Description(shortDefinition="The identity of a patient to list statements  for")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="Date when patient was taking (or not taking) the medication")
			@OptionalParam(name="effectivedate")
			DateRangeParam theEffectivedate, 
  
			@Description(shortDefinition="Return statements that match the given status")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="Who the information in the statement came from")
			@OptionalParam(name="source", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theSource, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"MedicationStatement:medication" , 					"MedicationStatement:patient" , 					"MedicationStatement:source" , 						"MedicationStatement:medication" , 					"MedicationStatement:patient" , 					"MedicationStatement:source" , 						"MedicationStatement:medication" , 					"MedicationStatement:patient" , 					"MedicationStatement:source" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("medication", theMedication);	
			paramMap.add("patient", thePatient);	
			paramMap.add("effectivedate", theEffectivedate);	
			paramMap.add("status", theStatus);	
			paramMap.add("source", theSource);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
