
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class MessageHeaderResourceProvider extends JpaResourceProviderDstu2<MessageHeader> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return MessageHeader.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="src-id")
			TokenAndListParam theSrc_id, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="timestamp")
			DateRangeParam theTimestamp, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="event")
			TokenAndListParam theEvent, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="response-id")
			TokenAndListParam theResponse_id, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source")
			StringAndListParam theSource, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source-uri")
			UriAndListParam theSource_uri, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="destination")
			StringAndListParam theDestination, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="destination-uri")
			UriAndListParam theDestination_uri, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="data", targetTypes={  } )
			ReferenceAndListParam theData, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="receiver", targetTypes={  Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam theReceiver, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="author", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theAuthor, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="responsible", targetTypes={  Practitioner.class ,   Organization.class   } )
			ReferenceAndListParam theResponsible, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="enterer", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theEnterer, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="target", targetTypes={  Device.class   } )
			ReferenceAndListParam theTarget, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"MessageHeader:author" , 					"MessageHeader:data" , 					"MessageHeader:enterer" , 					"MessageHeader:receiver" , 					"MessageHeader:responsible" , 					"MessageHeader:target" , 						"MessageHeader:author" , 					"MessageHeader:data" , 					"MessageHeader:enterer" , 					"MessageHeader:receiver" , 					"MessageHeader:responsible" , 					"MessageHeader:target" , 						"MessageHeader:author" , 					"MessageHeader:data" , 					"MessageHeader:enterer" , 					"MessageHeader:receiver" , 					"MessageHeader:responsible" , 					"MessageHeader:target" , 						"MessageHeader:author" , 					"MessageHeader:data" , 					"MessageHeader:enterer" , 					"MessageHeader:receiver" , 					"MessageHeader:responsible" , 					"MessageHeader:target" , 						"MessageHeader:author" , 					"MessageHeader:data" , 					"MessageHeader:enterer" , 					"MessageHeader:receiver" , 					"MessageHeader:responsible" , 					"MessageHeader:target" , 						"MessageHeader:author" , 					"MessageHeader:data" , 					"MessageHeader:enterer" , 					"MessageHeader:receiver" , 					"MessageHeader:responsible" , 					"MessageHeader:target" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("src-id", theSrc_id);	
			paramMap.add("timestamp", theTimestamp);	
			paramMap.add("event", theEvent);	
			paramMap.add("response-id", theResponse_id);	
			paramMap.add("code", theCode);	
			paramMap.add("source", theSource);	
			paramMap.add("source-uri", theSource_uri);	
			paramMap.add("destination", theDestination);	
			paramMap.add("destination-uri", theDestination_uri);	
			paramMap.add("data", theData);	
			paramMap.add("receiver", theReceiver);	
			paramMap.add("author", theAuthor);	
			paramMap.add("responsible", theResponsible);	
			paramMap.add("enterer", theEnterer);	
			paramMap.add("target", theTarget);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
