
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class NamingSystemResourceProvider extends JpaResourceProviderDstu2<NamingSystem> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return NamingSystem.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="country")
			TokenAndListParam theCountry, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="category")
			TokenAndListParam theCategory, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="responsible")
			StringAndListParam theResponsible, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="idtype")
			TokenAndListParam theIdtype, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="value")
			StringAndListParam theValue, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="period")
			DateRangeParam thePeriod, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="publisher")
			StringAndListParam thePublisher, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="contact")
			StringAndListParam theContact, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="telecom")
			TokenAndListParam theTelecom, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="replacedby", targetTypes={  NamingSystem.class   } )
			ReferenceAndListParam theReplacedby, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"NamingSystem:replacedby" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("type", theType);	
			paramMap.add("name", theName);	
			paramMap.add("date", theDate);	
			paramMap.add("status", theStatus);	
			paramMap.add("country", theCountry);	
			paramMap.add("category", theCategory);	
			paramMap.add("responsible", theResponsible);	
			paramMap.add("idtype", theIdtype);	
			paramMap.add("value", theValue);	
			paramMap.add("period", thePeriod);	
			paramMap.add("publisher", thePublisher);	
			paramMap.add("contact", theContact);	
			paramMap.add("telecom", theTelecom);	
			paramMap.add("replacedby", theReplacedby);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
