
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class NutritionOrderResourceProvider extends JpaResourceProviderDstu2<NutritionOrder> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return NutritionOrder.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The identity of the person who requires the diet, formula or nutritional supplement")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="The identify of the provider who placed the nutrition order")
			@OptionalParam(name="provider", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theProvider, 
  
			@Description(shortDefinition="Return nutrition orders with this external identity")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="Return nutrition orders with this encounter identity")
			@OptionalParam(name="encounter", targetTypes={  Encounter.class   } )
			ReferenceAndListParam theEncounter, 
  
			@Description(shortDefinition="Return nutrition orders requested on this date")
			@OptionalParam(name="datetime")
			DateRangeParam theDatetime, 
  
			@Description(shortDefinition="Status of the nutrition order.")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="Type of diet that can be consumed orally (i.e., take via the mouth).")
			@OptionalParam(name="oraldiet")
			TokenAndListParam theOraldiet, 
  
			@Description(shortDefinition="Type of supplement product requested")
			@OptionalParam(name="supplement")
			TokenAndListParam theSupplement, 
  
			@Description(shortDefinition="Type of enteral or infant formula")
			@OptionalParam(name="formula")
			TokenAndListParam theFormula, 
  
			@Description(shortDefinition="Type of module component to add to the feeding")
			@OptionalParam(name="additive")
			TokenAndListParam theAdditive, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"NutritionOrder:encounter" , 					"NutritionOrder:patient" , 					"NutritionOrder:provider" , 						"NutritionOrder:encounter" , 					"NutritionOrder:patient" , 					"NutritionOrder:provider" , 						"NutritionOrder:encounter" , 					"NutritionOrder:patient" , 					"NutritionOrder:provider" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("patient", thePatient);	
			paramMap.add("provider", theProvider);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("encounter", theEncounter);	
			paramMap.add("datetime", theDatetime);	
			paramMap.add("status", theStatus);	
			paramMap.add("oraldiet", theOraldiet);	
			paramMap.add("supplement", theSupplement);	
			paramMap.add("formula", theFormula);	
			paramMap.add("additive", theAdditive);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
