
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class OperationDefinitionResourceProvider extends JpaResourceProviderDstu2<OperationDefinition> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return OperationDefinition.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="url")
			UriAndListParam theUrl, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="version")
			TokenAndListParam theVersion, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="publisher")
			StringAndListParam thePublisher, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="kind")
			TokenAndListParam theKind, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="base", targetTypes={  OperationDefinition.class   } )
			ReferenceAndListParam theBase, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="system")
			TokenAndListParam theSystem, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="instance")
			TokenAndListParam theInstance, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="profile", targetTypes={  StructureDefinition.class   } )
			ReferenceAndListParam theProfile, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"OperationDefinition:base" , 					"OperationDefinition:profile" , 						"OperationDefinition:base" , 					"OperationDefinition:profile" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("url", theUrl);	
			paramMap.add("version", theVersion);	
			paramMap.add("name", theName);	
			paramMap.add("publisher", thePublisher);	
			paramMap.add("code", theCode);	
			paramMap.add("status", theStatus);	
			paramMap.add("date", theDate);	
			paramMap.add("kind", theKind);	
			paramMap.add("base", theBase);	
			paramMap.add("system", theSystem);	
			paramMap.add("type", theType);	
			paramMap.add("instance", theInstance);	
			paramMap.add("profile", theProfile);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
