
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class PersonResourceProvider extends JpaResourceProviderDstu2<Person> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Person.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="A person Identifier")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="A portion of name in any name part")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="A portion of name using some kind of phonetic matching algorithm")
			@OptionalParam(name="phonetic")
			StringAndListParam thePhonetic, 
  
			@Description(shortDefinition="The value in any kind of contact")
			@OptionalParam(name="telecom")
			TokenAndListParam theTelecom, 
  
			@Description(shortDefinition="An address in any kind of address/part")
			@OptionalParam(name="address")
			StringAndListParam theAddress, 
  
			@Description(shortDefinition="The gender of the person")
			@OptionalParam(name="gender")
			TokenAndListParam theGender, 
  
			@Description(shortDefinition="The person's date of birth")
			@OptionalParam(name="birthdate")
			DateRangeParam theBirthdate, 
  
			@Description(shortDefinition="The organization at which this person record is being managed")
			@OptionalParam(name="organization", targetTypes={  Organization.class   } )
			ReferenceAndListParam theOrganization, 
  
			@Description(shortDefinition="Any link has this Patient, Person, RelatedPerson or Practitioner reference")
			@OptionalParam(name="link", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Person.class   } )
			ReferenceAndListParam theLink, 
  
			@Description(shortDefinition="The Person links to this Patient")
			@OptionalParam(name="patient", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Person.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="The Person links to this Practitioner")
			@OptionalParam(name="practitioner", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Person.class   } )
			ReferenceAndListParam thePractitioner, 
  
			@Description(shortDefinition="The Person links to this RelatedPerson")
			@OptionalParam(name="relatedperson", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class ,   Person.class   } )
			ReferenceAndListParam theRelatedperson, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Person:link" , 					"Person:organization" , 					"Person:patient" , 					"Person:practitioner" , 					"Person:relatedperson" , 						"Person:link" , 					"Person:organization" , 					"Person:patient" , 					"Person:practitioner" , 					"Person:relatedperson" , 						"Person:link" , 					"Person:organization" , 					"Person:patient" , 					"Person:practitioner" , 					"Person:relatedperson" , 						"Person:link" , 					"Person:organization" , 					"Person:patient" , 					"Person:practitioner" , 					"Person:relatedperson" , 						"Person:link" , 					"Person:organization" , 					"Person:patient" , 					"Person:practitioner" , 					"Person:relatedperson" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("name", theName);	
			paramMap.add("phonetic", thePhonetic);	
			paramMap.add("telecom", theTelecom);	
			paramMap.add("address", theAddress);	
			paramMap.add("gender", theGender);	
			paramMap.add("birthdate", theBirthdate);	
			paramMap.add("organization", theOrganization);	
			paramMap.add("link", theLink);	
			paramMap.add("patient", thePatient);	
			paramMap.add("practitioner", thePractitioner);	
			paramMap.add("relatedperson", theRelatedperson);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
