
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ProcessResponseResourceProvider extends JpaResourceProviderDstu2<ProcessResponse> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ProcessResponse.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The business identifier of the Explanation of Benefit")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The reference to the claim")
			@OptionalParam(name="request", targetTypes={  } )
			ReferenceAndListParam theRequest, 
  
			@Description(shortDefinition="The organization who generated this resource")
			@OptionalParam(name="organization", targetTypes={  Organization.class   } )
			ReferenceAndListParam theOrganization, 
  
			@Description(shortDefinition="The Provider who is responsible the request transaction")
			@OptionalParam(name="requestprovider", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theRequestprovider, 
  
			@Description(shortDefinition="The Organization who is responsible the request transaction")
			@OptionalParam(name="requestorganization", targetTypes={  Organization.class   } )
			ReferenceAndListParam theRequestorganization, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"ProcessResponse:organization" , 					"ProcessResponse:request" , 					"ProcessResponse:requestorganization" , 					"ProcessResponse:requestprovider" , 						"ProcessResponse:organization" , 					"ProcessResponse:request" , 					"ProcessResponse:requestorganization" , 					"ProcessResponse:requestprovider" , 						"ProcessResponse:organization" , 					"ProcessResponse:request" , 					"ProcessResponse:requestorganization" , 					"ProcessResponse:requestprovider" , 						"ProcessResponse:organization" , 					"ProcessResponse:request" , 					"ProcessResponse:requestorganization" , 					"ProcessResponse:requestprovider" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("request", theRequest);	
			paramMap.add("organization", theOrganization);	
			paramMap.add("requestprovider", theRequestprovider);	
			paramMap.add("requestorganization", theRequestorganization);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
