
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class QuestionnaireAnswersResourceProvider extends JpaResourceProviderDstu2<QuestionnaireAnswers> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return QuestionnaireAnswers.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The status of the questionnaire answers")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="When the questionnaire was authored")
			@OptionalParam(name="authored")
			DateRangeParam theAuthored, 
  
			@Description(shortDefinition="The subject of the questionnaire")
			@OptionalParam(name="subject", targetTypes={  } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="The author of the questionnaire")
			@OptionalParam(name="author", targetTypes={  Device.class ,   Practitioner.class ,   Patient.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theAuthor, 
  
			@Description(shortDefinition="The questionnaire the answers are provided for")
			@OptionalParam(name="questionnaire", targetTypes={  Questionnaire.class   } )
			ReferenceAndListParam theQuestionnaire, 
  
			@Description(shortDefinition="Encounter during which questionnaire was authored")
			@OptionalParam(name="encounter", targetTypes={  Encounter.class   } )
			ReferenceAndListParam theEncounter, 
  
			@Description(shortDefinition="The patient that is the subject of the questionnaire")
			@OptionalParam(name="patient", targetTypes={  } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="source", targetTypes={  Patient.class ,   Practitioner.class ,   RelatedPerson.class   } )
			ReferenceAndListParam theSource, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"QuestionnaireAnswers:author" , 					"QuestionnaireAnswers:encounter" , 					"QuestionnaireAnswers:patient" , 					"QuestionnaireAnswers:questionnaire" , 					"QuestionnaireAnswers:source" , 					"QuestionnaireAnswers:subject" , 						"QuestionnaireAnswers:author" , 					"QuestionnaireAnswers:encounter" , 					"QuestionnaireAnswers:patient" , 					"QuestionnaireAnswers:questionnaire" , 					"QuestionnaireAnswers:source" , 					"QuestionnaireAnswers:subject" , 						"QuestionnaireAnswers:author" , 					"QuestionnaireAnswers:encounter" , 					"QuestionnaireAnswers:patient" , 					"QuestionnaireAnswers:questionnaire" , 					"QuestionnaireAnswers:source" , 					"QuestionnaireAnswers:subject" , 						"QuestionnaireAnswers:author" , 					"QuestionnaireAnswers:encounter" , 					"QuestionnaireAnswers:patient" , 					"QuestionnaireAnswers:questionnaire" , 					"QuestionnaireAnswers:source" , 					"QuestionnaireAnswers:subject" , 						"QuestionnaireAnswers:author" , 					"QuestionnaireAnswers:encounter" , 					"QuestionnaireAnswers:patient" , 					"QuestionnaireAnswers:questionnaire" , 					"QuestionnaireAnswers:source" , 					"QuestionnaireAnswers:subject" , 						"QuestionnaireAnswers:author" , 					"QuestionnaireAnswers:encounter" , 					"QuestionnaireAnswers:patient" , 					"QuestionnaireAnswers:questionnaire" , 					"QuestionnaireAnswers:source" , 					"QuestionnaireAnswers:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("status", theStatus);	
			paramMap.add("authored", theAuthored);	
			paramMap.add("subject", theSubject);	
			paramMap.add("author", theAuthor);	
			paramMap.add("questionnaire", theQuestionnaire);	
			paramMap.add("encounter", theEncounter);	
			paramMap.add("patient", thePatient);	
			paramMap.add("source", theSource);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
