
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class SpecimenResourceProvider extends JpaResourceProviderDstu2<Specimen> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Specimen.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The subject of the specimen")
			@OptionalParam(name="subject", targetTypes={  Patient.class ,   Group.class ,   Device.class ,   Substance.class   } )
			ReferenceAndListParam theSubject, 
  
			@Description(shortDefinition="The patient the specimen comes from")
			@OptionalParam(name="patient", targetTypes={  Patient.class ,   Group.class ,   Device.class ,   Substance.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="The unique identifier associated with the specimen")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The specimen type")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="The parent of the specimen")
			@OptionalParam(name="parent", targetTypes={  Specimen.class   } )
			ReferenceAndListParam theParent, 
  
			@Description(shortDefinition="The accession number associated with the specimen")
			@OptionalParam(name="accession")
			TokenAndListParam theAccession, 
  
			@Description(shortDefinition="The date the specimen was collected")
			@OptionalParam(name="collected")
			DateRangeParam theCollected, 
  
			@Description(shortDefinition="Who collected the specimen")
			@OptionalParam(name="collector", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theCollector, 
  
			@Description(shortDefinition="The code for the body site from where the specimen originated")
			@OptionalParam(name="site-code")
			TokenAndListParam theSite_code, 
  
			@Description(shortDefinition="BodySite resource for the body site from where the specimen originated")
			@OptionalParam(name="site-reference", targetTypes={  } )
			ReferenceAndListParam theSite_reference, 
  
			@Description(shortDefinition="The unique identifier associated with the specimen container")
			@OptionalParam(name="containerid")
			TokenAndListParam theContainerid, 
  
			@Description(shortDefinition="The kind of specimen container")
			@OptionalParam(name="container")
			TokenAndListParam theContainer, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Specimen:collector" , 					"Specimen:parent" , 					"Specimen:patient" , 					"Specimen:site-reference" , 					"Specimen:subject" , 						"Specimen:collector" , 					"Specimen:parent" , 					"Specimen:patient" , 					"Specimen:site-reference" , 					"Specimen:subject" , 						"Specimen:collector" , 					"Specimen:parent" , 					"Specimen:patient" , 					"Specimen:site-reference" , 					"Specimen:subject" , 						"Specimen:collector" , 					"Specimen:parent" , 					"Specimen:patient" , 					"Specimen:site-reference" , 					"Specimen:subject" , 						"Specimen:collector" , 					"Specimen:parent" , 					"Specimen:patient" , 					"Specimen:site-reference" , 					"Specimen:subject" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("subject", theSubject);	
			paramMap.add("patient", thePatient);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("type", theType);	
			paramMap.add("parent", theParent);	
			paramMap.add("accession", theAccession);	
			paramMap.add("collected", theCollected);	
			paramMap.add("collector", theCollector);	
			paramMap.add("site-code", theSite_code);	
			paramMap.add("site-reference", theSite_reference);	
			paramMap.add("containerid", theContainerid);	
			paramMap.add("container", theContainer);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
