
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class StructureDefinitionResourceProvider extends JpaResourceProviderDstu2<StructureDefinition> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return StructureDefinition.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="url")
			UriAndListParam theUrl, 
  
			@Description(shortDefinition="The identifier of the profile")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The version identifier of the profile")
			@OptionalParam(name="version")
			TokenAndListParam theVersion, 
  
			@Description(shortDefinition="Name of the profile")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="Name of the publisher of the profile")
			@OptionalParam(name="publisher")
			StringAndListParam thePublisher, 
  
			@Description(shortDefinition="Text search in the description of the profile")
			@OptionalParam(name="description")
			StringAndListParam theDescription, 
  
			@Description(shortDefinition="The current status of the profile")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="The profile publication date")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="A code for the profile")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="A vocabulary binding reference")
			@OptionalParam(name="valueset", targetTypes={  } )
			ReferenceAndListParam theValueset, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="type")
			TokenAndListParam theType, 
  
			@Description(shortDefinition="A path that is constrained in the profile")
			@OptionalParam(name="path")
			TokenAndListParam thePath, 
  
			@Description(shortDefinition="A use context assigned to the structure")
			@OptionalParam(name="context")
			TokenAndListParam theContext, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="display")
			StringAndListParam theDisplay, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="experimental")
			TokenAndListParam theExperimental, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="abstract")
			TokenAndListParam theAbstract, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="context-type")
			TokenAndListParam theContext_type, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="ext-context")
			StringAndListParam theExt_context, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="base")
			UriAndListParam theBase, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"StructureDefinition:valueset" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("url", theUrl);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("version", theVersion);	
			paramMap.add("name", theName);	
			paramMap.add("publisher", thePublisher);	
			paramMap.add("description", theDescription);	
			paramMap.add("status", theStatus);	
			paramMap.add("date", theDate);	
			paramMap.add("code", theCode);	
			paramMap.add("valueset", theValueset);	
			paramMap.add("type", theType);	
			paramMap.add("path", thePath);	
			paramMap.add("context", theContext);	
			paramMap.add("display", theDisplay);	
			paramMap.add("experimental", theExperimental);	
			paramMap.add("abstract", theAbstract);	
			paramMap.add("context-type", theContext_type);	
			paramMap.add("ext-context", theExt_context);	
			paramMap.add("base", theBase);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
