
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class SupplyResourceProvider extends JpaResourceProviderDstu2<Supply> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return Supply.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="kind")
			TokenAndListParam theKind, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="patient", targetTypes={  Patient.class   } )
			ReferenceAndListParam thePatient, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="supplier", targetTypes={  Practitioner.class   } )
			ReferenceAndListParam theSupplier, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dispenseid")
			TokenAndListParam theDispenseid, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="dispensestatus")
			TokenAndListParam theDispensestatus, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
					"Supply:patient" , 					"Supply:supplier" , 						"Supply:patient" , 					"Supply:supplier" 					, "*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("kind", theKind);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("status", theStatus);	
			paramMap.add("patient", thePatient);	
			paramMap.add("supplier", theSupplier);	
			paramMap.add("dispenseid", theDispenseid);	
			paramMap.add("dispensestatus", theDispensestatus);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
