
package ca.uhn.fhir.jpa.rp.dstu2;

import java.util.*;

import org.apache.commons.lang3.StringUtils;

import ca.uhn.fhir.jpa.provider.JpaResourceProviderDstu2;
import ca.uhn.fhir.jpa.dao.SearchParameterMap;
import ca.uhn.fhir.model.api.*;
import ca.uhn.fhir.model.api.annotation.*;
import ca.uhn.fhir.model.dstu2.composite.*;
import ca.uhn.fhir.model.dstu2.resource.*;
import ca.uhn.fhir.rest.annotation.*;
import ca.uhn.fhir.rest.param.*;
import ca.uhn.fhir.rest.api.SortSpec;
import ca.uhn.fhir.model.dstu.resource.Binary;
// import ca.uhn.fhir.model.dstu2.resource.Bundle;
import ca.uhn.fhir.model.api.Bundle;

public class ValueSetResourceProvider extends JpaResourceProviderDstu2<ValueSet> {

	@Override
	public Class<? extends IResource> getResourceType() {
		return ValueSet.class;
	}

	@Search()
	public ca.uhn.fhir.rest.server.IBundleProvider search(
			javax.servlet.http.HttpServletRequest theServletRequest,
	
			@Description(shortDefinition="The resource identity")
			@OptionalParam(name="_id")
			StringParam theId, 

			@Description(shortDefinition="The resource language")
			@OptionalParam(name="_language")
			StringParam theResourceLanguage, 
  
			@Description(shortDefinition="The logical url for the value set")
			@OptionalParam(name="url")
			UriAndListParam theUrl, 
  
			@Description(shortDefinition="The identifier for the value set")
			@OptionalParam(name="identifier")
			TokenAndListParam theIdentifier, 
  
			@Description(shortDefinition="The version identifier of the value set")
			@OptionalParam(name="version")
			TokenAndListParam theVersion, 
  
			@Description(shortDefinition="The name of the value set")
			@OptionalParam(name="name")
			StringAndListParam theName, 
  
			@Description(shortDefinition="Name of the publisher of the value set")
			@OptionalParam(name="publisher")
			StringAndListParam thePublisher, 
  
			@Description(shortDefinition="Text search in the description of the value set")
			@OptionalParam(name="description")
			StringAndListParam theDescription, 
  
			@Description(shortDefinition="The status of the value set")
			@OptionalParam(name="status")
			TokenAndListParam theStatus, 
  
			@Description(shortDefinition="The value set publication date")
			@OptionalParam(name="date")
			DateRangeParam theDate, 
  
			@Description(shortDefinition="The system for any codes defined by this value set")
			@OptionalParam(name="system")
			UriAndListParam theSystem, 
  
			@Description(shortDefinition="A code defined in the value set")
			@OptionalParam(name="code")
			TokenAndListParam theCode, 
  
			@Description(shortDefinition="A code system included or excluded in the value set or an imported value set")
			@OptionalParam(name="reference")
			UriAndListParam theReference, 
  
			@Description(shortDefinition="A use context assigned to the value set")
			@OptionalParam(name="context")
			TokenAndListParam theContext, 
  
			@Description(shortDefinition="")
			@OptionalParam(name="expansion")
			UriAndListParam theExpansion, 

			@IncludeParam(reverse=true)
			Set<Include> theRevIncludes,

			@IncludeParam(allow= {
				"*"
			}) 
			Set<Include> theIncludes,
			
			@Sort 
			SortSpec theSort,
			
			@Count
			Integer theCount
	) {
		startRequest(theServletRequest);
		try {
			SearchParameterMap paramMap = new SearchParameterMap();
			paramMap.add("_id", theId);		
			paramMap.add("_language", theResourceLanguage);			
			paramMap.add("url", theUrl);	
			paramMap.add("identifier", theIdentifier);	
			paramMap.add("version", theVersion);	
			paramMap.add("name", theName);	
			paramMap.add("publisher", thePublisher);	
			paramMap.add("description", theDescription);	
			paramMap.add("status", theStatus);	
			paramMap.add("date", theDate);	
			paramMap.add("system", theSystem);	
			paramMap.add("code", theCode);	
			paramMap.add("reference", theReference);	
			paramMap.add("context", theContext);	
			paramMap.add("expansion", theExpansion);	
			paramMap.setRevIncludes(theRevIncludes);
			paramMap.setIncludes(theIncludes);
			paramMap.setSort(theSort);
			paramMap.setCount(theCount);

			ca.uhn.fhir.rest.server.IBundleProvider retVal = getDao().search(paramMap);
			return retVal;
		} finally {
			endRequest(theServletRequest);
		}
	}




}
